0.5.0 - 18 Apr, 2016
++++++++++++++++++++

Features
~~~~~~~~
- `#7485 <https://leap.se/code/issues/7485>`_: Move validation, usage and audited date to the active document.
- `#7713 <https://leap.se/code/issues/7713>`_: Update soledad documents by adding versioning field.
- `#7500 <https://leap.se/code/issues/7500>`_: Use fingerprints instead of key ids.
- `#7712 <https://leap.se/code/issues/7712>`_: Document the soledad docs fields.
- Make EncryptionKey aware of the active address.

Bugfixes
~~~~~~~~
- `#7974 <https://leap.se/code/issues/7974>`_: Return KeyNotFound Failure if not valid key is given to put_raw_key.

Misc
~~~~
- This version includes changes in the Soledad Documents and minor modifications to the API.
- Changelog migrated to rst.
